# Generated by Django 2.0.1 on 2018-01-16 10:35

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("edc_identifier", "0014_auto_20180103_1322")]

    operations = [migrations.AlterModelManagers(name="identifiermodel", managers=[])]
